import Moment from 'moment';
import React from 'react';
import {Image, View} from 'react-native';
import {IMAGES} from '../../../../values/images';
import styles from '../../style';

import SelectDropdown from 'react-native-select-dropdown';
import AppText from '../../../../components/AppText';

const StatisticsConfirmWorkdays = ({
  dataChart,
  onChangeMonthFilter,
  dayPress,
}) => {
  const typeChartColor = [
    {color: '#7d93ff', name: 'Trên 6h'},
    {color: '#9eaeff', name: '4-6h'},
    {color: '#bec9ff', name: '2-4h'},
    {color: '#dfe4ff', name: '0-2h'},
    {color: '#f2f2f2', name: '0h'},
  ];

  //console.log(dataChart?.data);
  const dayOfWeek = [
    'Monday',
    'Tuesday',
    'Wednesday',
    'Thursday',
    'Friday',
    'Saturday',
    'Sunday',
  ];

  return (
    <View style={{padding: 15, backgroundColor: 'white'}}>
      <AppText style={[styles.title, {marginBottom: 20}]}>
        Thống kê xác nhận ngày công của tôi
      </AppText>
      <SelectDropdown
        data={[
          'Tháng 01',
          'Tháng 02',
          'Tháng 03',
          'Tháng 04',
          'Tháng 05',
          'Tháng 06',
          'Tháng 07',
          'Tháng 08',
          'Tháng 09',
          'Tháng 10',
          'Tháng 11',
          'Tháng 12',
        ]}
        dropdownIconPosition={'right'}
        defaultButtonText={'Tháng ' + (new Date().getMonth() + 1)}
        buttonStyle={styles.dropdown1BtnStyle}
        onSelect={selectedItem => onChangeMonthFilter(selectedItem)}
        dropdownStyle={styles.dropdown1DropdownStyle}
        rowStyle={styles.dropdown1RowStyle}
        rowTextStyle={styles.dropdown1RowTxtStyle}
        buttonTextStyle={styles.dropdown1BtnTxtStyle}
        renderDropdownIcon={isOpened => {
          return (
            <Image
              source={isOpened ? IMAGES.IcUpArrow : IMAGES.IcArrowDown}
              style={{width: 20, height: 20}}
            />
          );
        }}
      />

      <View style={{flexDirection: 'row', marginTop: 20}}>
        <View style={styles.viewCalendar}>
          <View style={styles.viewDayOfWeek}>
            <AppText style={{fontSize: 12, fontWeight: 'bold'}}>T2</AppText>
            <AppText style={{fontSize: 12, fontWeight: 'bold'}}>T3</AppText>
            <AppText style={{fontSize: 12, fontWeight: 'bold'}}>T4</AppText>
            <AppText style={{fontSize: 12, fontWeight: 'bold'}}>T5</AppText>
            <AppText style={{fontSize: 12, fontWeight: 'bold'}}>T6</AppText>
            <AppText style={{fontSize: 12, fontWeight: 'bold'}}>T7</AppText>
            <AppText style={{fontSize: 12, fontWeight: 'bold'}}>CN</AppText>
          </View>
          {dataChart?.data.length > 0 &&
            dataChart?.data?.map((item, index) => {
              let flag = false;
              return (
                <View key={index}>
                  {(index == 0 && (
                    <View
                      style={{
                        flexDirection: 'row',
                      }}>
                      {dayOfWeek.map((el, i) => {
                        if (flag) return true;
                        if (Moment(item.date).format('dddd') === el) {
                          flag = true;
                          return (
                            <View
                              key={i}
                              style={{
                                width: 30,
                                height: 30,
                                backgroundColor:
                                  (parseInt(item.absent_hours) > 6 &&
                                    '#7d93ff') ||
                                  (parseInt(item.absent_hours) >= 4 &&
                                    parseInt(item.absent_hours) <= 6 &&
                                    '#7d93ff') ||
                                  (parseInt(item.absent_hours) >= 2 &&
                                    parseInt(item.absent_hours) <= 4 &&
                                    '#7d93ff') ||
                                  (parseInt(item.absent_hours) > 0 &&
                                    parseInt(item.absent_hours) <= 2 &&
                                    '#dfe4ff') ||
                                  '#f2f2f2',
                                justifyContent: 'center',
                                alignItems: 'center',
                                margin: 2,
                              }}>
                              {
                                <AppText>{`${new Date(
                                  item.date,
                                ).getDate()}`}</AppText>
                              }
                            </View>
                          );
                        } else {
                          return (
                            <View
                              key={i}
                              style={{
                                width: 30,
                                height: 30,
                                backgroundColor: '#f2f2f2',
                                justifyContent: 'center',
                                alignItems: 'center',
                                margin: 2,
                              }}></View>
                          );
                        }
                      })}
                    </View>
                  )) || (
                    <View
                      style={{
                        width: 30,
                        height: 30,
                        backgroundColor:
                          (parseInt(item.absent_hours) > 6 && '#7d93ff') ||
                          (parseInt(item.absent_hours) >= 4 &&
                            parseInt(item.absent_hours) <= 6 &&
                            '#7d93ff') ||
                          (parseInt(item.absent_hours) >= 2 &&
                            parseInt(item.absent_hours) <= 4 &&
                            '#7d93ff') ||
                          (parseInt(item.absent_hours) > 0 &&
                            parseInt(item.absent_hours) <= 2 &&
                            '#dfe4ff') ||
                          '#f2f2f2',
                        justifyContent: 'center',
                        alignItems: 'center',
                        margin: 2,
                      }}>
                      {<AppText>{`${new Date(item.date).getDate()}`}</AppText>}
                    </View>
                  )}
                </View>
              );
            })}
        </View>
        <View style={{marginLeft: 30}}>
          {typeChartColor &&
            typeChartColor.map((item, i) => (
              <View key={i} style={{flexDirection: 'row'}}>
                <View
                  style={{
                    width: 20,
                    height: 20,
                    marginRight: 10,
                    marginBottom: 2,
                    backgroundColor: item.color,
                  }}
                />
                <AppText style={{fontSize: 11}}>{item.name}</AppText>
              </View>
            ))}
          <View style={{marginTop: 10}}>
            {dayPress && <AppText>{dayPress}</AppText>}
          </View>
        </View>
      </View>
    </View>
  );
};

export default StatisticsConfirmWorkdays;
